@@ -4,7 +4,7 @@
  *  somewhat obsolete (most of this can be replaced by exceptions). */
 
 /*
- *  GiNaC Copyright (C) 1999-2008 Johannes Gutenberg University Mainz, Germany
+ *  GiNaC Copyright (C) 1999-2010 Johannes Gutenberg University Mainz, Germany
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,10 +21,11 @@
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef __GINAC_FAIL_H__
-#define __GINAC_FAIL_H__
+#ifndef GINAC_FAIL_H
+#define GINAC_FAIL_H
 
 #include "basic.h"
+#include "archive.h"
 
 namespace GiNaC {
 
@@ -40,7 +41,8 @@ protected:
 protected:
 	void do_print(const print_context & c, unsigned level) const;
 };
+GINAC_DECLARE_UNARCHIVER(fail);
 
 } // namespace GiNaC
 
-#endif // ndef __GINAC_FAIL_H__
+#endif // ndef GINAC_FAIL_H
