@@ -3,7 +3,7 @@
  *  Interface to parser context. */
 
 /*
- *  GiNaC Copyright (C) 1999-2009 Johannes Gutenberg University Mainz, Germany
+ *  GiNaC Copyright (C) 1999-2010 Johannes Gutenberg University Mainz, Germany
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -41,12 +41,12 @@ namespace GiNaC {
 typedef std::map<std::string, ex> symtab;
 
 /**
- * Find the symbol with the @a name in the symbol table @a syms.
+ * Find the symbol (or abbreviation) with the @a name in the symbol table @a syms.
  *
  * If symbol is missing and @a strict = false, insert it, otherwise
  * throw an exception.
  */
-extern symbol
+extern ex 
 find_or_insert_symbol(const std::string& name, symtab& syms,
 	              const bool strict);
 
@@ -93,9 +93,15 @@ typedef std::map<prototype, reader_func> prototype_table;
 /**
  * Default prototype table.
  *
- * It supports most of builtin GiNaC functions.
+ * It supports all defined GiNaC functions and "pow", "sqrt", and "power".
  */
 extern const prototype_table& get_default_reader();
+/**
+ * Builtin prototype table.
+ *
+ * It supports only the builtin GiNaC functions and "pow", "sqrt", and "power".
+ */
+extern const prototype_table& get_builtin_reader();
 
 } // namespace GiNaC
 
